@@ -12,10 +12,18 @@ Usage::
 import sys
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_imagebuilder.literals import (
+    ComponentType,
+    ContainerRepositoryService,
+    ContainerType,
+    EbsVolumeType,
+    ImageStatus,
+    ImageType,
+    PipelineExecutionStartCondition,
+    PipelineStatus,
+    Platform,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -141,9 +149,9 @@ ComponentSummaryTypeDef = TypedDict(
         "arn": str,
         "name": str,
         "version": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "supportedOsVersions": List[str],
-        "type": Literal["BUILD", "TEST"],
+        "type": ComponentType,
         "owner": str,
         "description": str,
         "changeDescription": str,
@@ -161,8 +169,8 @@ ComponentTypeDef = TypedDict(
         "version": str,
         "description": str,
         "changeDescription": str,
-        "type": Literal["BUILD", "TEST"],
-        "platform": Literal["Windows", "Linux"],
+        "type": ComponentType,
+        "platform": Platform,
         "supportedOsVersions": List[str],
         "owner": str,
         "data": str,
@@ -181,9 +189,9 @@ ComponentVersionTypeDef = TypedDict(
         "name": str,
         "version": str,
         "description": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "supportedOsVersions": List[str],
-        "type": Literal["BUILD", "TEST"],
+        "type": ComponentType,
         "owner": str,
         "dateCreated": str,
     },
@@ -212,9 +220,9 @@ ContainerRecipeSummaryTypeDef = TypedDict(
     "ContainerRecipeSummaryTypeDef",
     {
         "arn": str,
-        "containerType": Literal["DOCKER"],
+        "containerType": ContainerType,
         "name": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "owner": str,
         "parentImage": str,
         "dateCreated": str,
@@ -227,10 +235,10 @@ ContainerRecipeTypeDef = TypedDict(
     "ContainerRecipeTypeDef",
     {
         "arn": str,
-        "containerType": Literal["DOCKER"],
+        "containerType": ContainerType,
         "name": str,
         "description": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "owner": str,
         "version": str,
         "components": List["ComponentConfigurationTypeDef"],
@@ -315,7 +323,7 @@ EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
         "kmsKeyId": str,
         "snapshotId": str,
         "volumeSize": int,
-        "volumeType": Literal["standard", "io1", "io2", "gp2", "gp3", "sc1", "st1"],
+        "volumeType": EbsVolumeType,
     },
     total=False,
 )
@@ -330,7 +338,7 @@ ImagePipelineTypeDef = TypedDict(
         "arn": str,
         "name": str,
         "description": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "enhancedImageMetadataEnabled": bool,
         "imageRecipeArn": str,
         "containerRecipeArn": str,
@@ -338,7 +346,7 @@ ImagePipelineTypeDef = TypedDict(
         "distributionConfigurationArn": str,
         "imageTestsConfiguration": "ImageTestsConfigurationTypeDef",
         "schedule": "ScheduleTypeDef",
-        "status": Literal["DISABLED", "ENABLED"],
+        "status": PipelineStatus,
         "dateCreated": str,
         "dateUpdated": str,
         "dateLastRun": str,
@@ -353,7 +361,7 @@ ImageRecipeSummaryTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "owner": str,
         "parentImage": str,
         "dateCreated": str,
@@ -366,10 +374,10 @@ ImageRecipeTypeDef = TypedDict(
     "ImageRecipeTypeDef",
     {
         "arn": str,
-        "type": Literal["AMI", "DOCKER"],
+        "type": ImageType,
         "name": str,
         "description": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "owner": str,
         "version": str,
         "components": List["ComponentConfigurationTypeDef"],
@@ -383,24 +391,7 @@ ImageRecipeTypeDef = TypedDict(
 )
 
 ImageStateTypeDef = TypedDict(
-    "ImageStateTypeDef",
-    {
-        "status": Literal[
-            "PENDING",
-            "CREATING",
-            "BUILDING",
-            "TESTING",
-            "DISTRIBUTING",
-            "INTEGRATING",
-            "AVAILABLE",
-            "CANCELLED",
-            "FAILED",
-            "DEPRECATED",
-            "DELETED",
-        ],
-        "reason": str,
-    },
-    total=False,
+    "ImageStateTypeDef", {"status": ImageStatus, "reason": str}, total=False
 )
 
 ImageSummaryTypeDef = TypedDict(
@@ -408,9 +399,9 @@ ImageSummaryTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "type": Literal["AMI", "DOCKER"],
+        "type": ImageType,
         "version": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "osVersion": str,
         "state": "ImageStateTypeDef",
         "owner": str,
@@ -431,10 +422,10 @@ ImageTypeDef = TypedDict(
     "ImageTypeDef",
     {
         "arn": str,
-        "type": Literal["AMI", "DOCKER"],
+        "type": ImageType,
         "name": str,
         "version": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "enhancedImageMetadataEnabled": bool,
         "osVersion": str,
         "state": "ImageStateTypeDef",
@@ -457,9 +448,9 @@ ImageVersionTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "type": Literal["AMI", "DOCKER"],
+        "type": ImageType,
         "version": str,
-        "platform": Literal["Windows", "Linux"],
+        "platform": Platform,
         "osVersion": str,
         "owner": str,
         "dateCreated": str,
@@ -559,15 +550,14 @@ ScheduleTypeDef = TypedDict(
     {
         "scheduleExpression": str,
         "timezone": str,
-        "pipelineExecutionStartCondition": Literal[
-            "EXPRESSION_MATCH_ONLY", "EXPRESSION_MATCH_AND_DEPENDENCY_UPDATES_AVAILABLE"
-        ],
+        "pipelineExecutionStartCondition": PipelineExecutionStartCondition,
     },
     total=False,
 )
 
 TargetContainerRepositoryTypeDef = TypedDict(
-    "TargetContainerRepositoryTypeDef", {"service": Literal["ECR"], "repositoryName": str}
+    "TargetContainerRepositoryTypeDef",
+    {"service": ContainerRepositoryService, "repositoryName": str},
 )
 
 CancelImageCreationResponseTypeDef = TypedDict(
